@@ -23,18 +23,18 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare',
+ 'CFLAGS': '-Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
                             '-Werror=odr -Werror=lto-type-mismatch '
                             '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                            '-flto -fuse-linker-plugin -ffat-lto-objects -g '
-                            '-std=c11 -Wextra -Wno-unused-parameter '
+                            '-fno-semantic-interposition -flto '
+                            '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                            '-Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -44,7 +44,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
                              '-Wl,-z,pack-relative-relocs -Werror=odr '
                              '-Werror=lto-type-mismatch '
-                             '-Werror=strict-aliasing -flto -flto '
+                             '-Werror=strict-aliasing -flto '
+                             '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g',
  'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
@@ -63,12 +64,18 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--with-assertions' '--disable-optimizations' "
+                "'--without-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
+                "'PKG_CONFIG_PATH=/usr/share/guile-data/3.0/pkgconfig' "
+                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'PROFILE_TASK=-m test -j32 --pgo-extended -u-network "
+                '--timeout 1200 -x test_gdb -x test_pretty_print -x '
+                'test_dtrace -x test_asyncio -x test_concurrent_futures -x '
+                'test_httpservers -x test_logging -x test_multiprocessing_fork '
+                "-x test_socket -x test_xmlrpc -x test_tools'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
@@ -188,7 +195,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DB_H': 1,
+ 'HAVE_DB_H': 0,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -328,7 +335,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LIBB2': 1,
- 'HAVE_LIBDB': 1,
+ 'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBGDBM_COMPAT': 1,
@@ -619,21 +626,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
-                 '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+            '-c',
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+                 '-c -m 644',
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -642,13 +649,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
-                    '-Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
-                    '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
+                    '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -656,13 +665,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
-                    '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
-                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                    '-ffat-lto-objects -flto -fuse-linker-plugin '
+                    '-DNDEBUG -O2 -pipe -march=x86-64 -mtune=generic '
+                    '-Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -916,7 +927,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '',
+ 'OPT': '-DNDEBUG',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -933,7 +944,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j32 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_pretty_print -x test_dtrace -x test_asyncio '
+                 '-x test_concurrent_futures -x test_httpservers -x '
+                 'test_logging -x test_multiprocessing_fork -x test_socket -x '
+                 'test_xmlrpc -x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -952,61 +967,69 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
                              '-mtune=generic -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                             '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                             '-fno-semantic-interposition -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g '
                              '-std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare',
+ 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
  'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                     '-ffat-lto-objects -flto -fuse-linker-plugin '
-                     '-ffat-lto-objects -g -std=c11 -Wextra '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
+                     '-ffat-lto-objects -fno-semantic-interposition -flto '
+                     '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                     '-Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
-                   '-Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
+                   '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g',
+                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                       '-Werror=odr -Werror=lto-type-mismatch '
-                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-Werror=strict-aliasing -flto '
+                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -g',
  'PY_LDFLAGS_NOLTO': '-fno-lto',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
-                        '-Werror=odr -Werror=lto-type-mismatch '
-                        '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
-                        '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                        '-Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
+                        '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
+                        '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -g -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
